@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Thu Dec 29 12:03:00 PST 2011
+ * Generated Sun May  6 16:21:18 PDT 2012
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD 1
@@ -46,7 +46,7 @@ LOCAL void
 initialize(int arg_ct, char** arg_vec);
 
 LOCAL void
-config_dep(tOptions * pOptions, tOptDesc * pOptDesc);
+config_dep(tOptions * opts, tOptDesc * od);
 
 /*
  *  Extracted from agShell.c
@@ -54,8 +54,8 @@ config_dep(tOptions * pOptions, tOptDesc * pOptDesc);
 LOCAL void
 close_server_shell(void);
 
-LOCAL char*
-shell_cmd(char const * pzCmd);
+LOCAL char *
+shell_cmd(char const * cmd);
 
 /*
  *  Extracted from agUtils.c
@@ -70,22 +70,22 @@ LOCAL void
 check_make_dep_env(void);
 
 LOCAL void
-doOptions(int arg_ct, char ** arg_vec);
+process_ag_opts(int arg_ct, char ** arg_vec);
 
 LOCAL char const *
-getDefine(char const * pzDefName, ag_bool check_env);
+get_define_str(char const * de_name, bool check_env);
 
-LOCAL char*
-spanQuote(char* pzQte);
+LOCAL char *
+span_quote(char * in_q);
 
 LOCAL char const *
-skipScheme(char const * pzSrc,  char const * pzEnd);
+skip_scheme(char const * scan,  char const * end);
 
 LOCAL int
 count_nl(char const * pz);
 
 LOCAL char const *
-skipExpression(char const * pzSrc, size_t len);
+skip_expr(char const * pzSrc, size_t len);
 
 /*
  *  Extracted from autogen.c
@@ -116,16 +116,16 @@ processDirective(char* pzScan);
  *  Extracted from defFind.c
  */
 LOCAL int
-canonicalizeName(char* pzD, char const* pzS, int srcLen);
+canonical_name(char * pzD, char const * pzS, int srcLen);
 
-LOCAL tDefEntry*
-findDefEntry(char * pzName, ag_bool* pIsIndexed);
+LOCAL def_ent_t *
+find_def_ent(char * name, bool * indexed);
 
 LOCAL void
 print_used_defines(void);
 
-LOCAL tDefEntry**
-findEntryList(char* pzName);
+LOCAL def_ent_t **
+find_def_ent_list(char * name);
 
 /*
  *  Extracted from defLex.c
@@ -139,20 +139,20 @@ yyerror(char* s);
 /*
  *  Extracted from defLoad.c
  */
-LOCAL tDefEntry*
-getEntry(void);
+LOCAL def_ent_t *
+new_def_ent(void);
 
 LOCAL void
-print_def(tDefEntry * pDef);
+print_ent(def_ent_t * pDef);
 
-LOCAL tDefEntry*
-findPlace(char* name, char const * pzIndex);
+LOCAL def_ent_t *
+number_and_insert_ent(char * name, char const * idx_str);
 
 LOCAL void
-readDefines(void);
+read_defs(void);
 
 LOCAL void
-unloadDefs(void);
+unload_defs(void);
 
 /*
  *  Extracted from expGuile.c
@@ -168,7 +168,7 @@ ag_scm_c_eval_string_from_file_line(
  *  Extracted from expOutput.c
  */
 LOCAL void
-make_readonly(int fd);
+make_readonly(void);
 
 LOCAL void
 open_output_file(char const * fname, size_t nmsz, char const * mode, int flags);
@@ -189,19 +189,40 @@ do_multi_subs(char ** ppzStr, ssize_t * pStrLen, SCM match, SCM repl);
  *  Extracted from funcDef.c
  */
 LOCAL void
-parseMacroArgs(tTemplate* pT, tMacro* pMac);
+parse_mac_args(templ_t * pT, macro_t * mac);
 
 /*
  *  Extracted from funcEval.c
  */
 LOCAL char const *
-resolveSCM(SCM s);
+scm2display(SCM s);
 
 LOCAL char const *
-evalExpression(ag_bool* pMustFree);
+eval_mac_expr(bool * allocated);
 
 LOCAL SCM
-eval(char const* pzExpr);
+eval(char const * expr);
+
+/*
+ *  Extracted from funcFor.c
+ */
+LOCAL for_state_t *
+new_for_context(void);
+
+LOCAL void
+free_for_context(bool everything);
+
+/*
+ *  Extracted from functions.c
+ */
+LOCAL loop_jmp_type_t
+call_gen_block(jmp_buf jbuf, templ_t * tpl, macro_t * mac, macro_t * end_mac);
+
+LOCAL void
+gen_new_block(templ_t * tpl);
+
+LOCAL macro_t *
+mLoad_Leave(templ_t * tpl, macro_t * mac, char const ** p_scan);
 
 /*
  *  Extracted from loadPseudo.c
@@ -233,44 +254,44 @@ ag_scm2zchars(SCM s, const char * type);
 /*
  *  Extracted from tpLoad.c
  */
-LOCAL tTemplate *
-findTemplate(char const * pzTemplName);
+LOCAL templ_t *
+find_tpl(char const * pzTemplName);
 
 LOCAL tSuccess
-findFile(char const * pzFName,
-         char * pzFullName,
-         char const * const * papSuffixList,
-         char const * pzReferrer);
+find_file(char const * pzFName,
+          char * pzFullName,
+          char const * const * papSuffixList,
+          char const * pzReferrer);
 
-LOCAL tTemplate *
-loadTemplate(char const * pzFileName, char const * referrer);
+LOCAL templ_t *
+tpl_load(char const * fname, char const * referrer);
 
 LOCAL void
-unloadTemplate(tTemplate* pT);
+tpl_unload(templ_t * tpl);
 
 LOCAL void
-cleanup(tTemplate* pTF);
+cleanup(templ_t * tpl);
 
 /*
  *  Extracted from tpParse.c
  */
-LOCAL tMacro*
-parseTemplate(tMacro* pM, char const ** ppzText);
+LOCAL macro_t *
+parse_tpl(macro_t * mac, char const ** p_scan);
 
 /*
  *  Extracted from tpProcess.c
  */
 LOCAL void
-generateBlock(tTemplate * pT, tMacro * pMac, tMacro * pEnd);
+gen_block(templ_t * tpl, macro_t * mac, macro_t * emac);
 
-LOCAL tOutSpec *
-nextOutSpec(tOutSpec * pOS);
+LOCAL out_spec_t *
+next_out_spec(out_spec_t * os);
 
 LOCAL void
-processTemplate(tTemplate* pTF);
+process_tpl(templ_t * tpl);
 
 LOCAL void
-out_close(ag_bool purge);
+out_close(bool purge);
 
 #ifdef REDEF_LOCAL
 #  undef LOCAL
