@@ -2,7 +2,7 @@
 /**
  * @file tpLoad.c
  *
- * Time-stamp:        "2012-01-29 09:24:26 bkorb"
+ * Time-stamp:        "2012-04-07 09:03:08 bkorb"
  *
  *  This module will load a template and return a template structure.
  *
@@ -23,34 +23,32 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-static tTlibMark magicMark = TEMPLATE_MAGIC_MARKER;
-
 /* = = = START-STATIC-FORWARD = = = */
-static ag_bool
+static bool
 read_okay(char const * pzFName);
 
 static size_t
 cnt_macros(char const * pz);
 
 static void
-load_macs(tTemplate * pT, char const * pzF, char const * pzN,
+load_macs(templ_t * pT, char const * pzF, char const * pzN,
           char const * pzData);
 
-static tTemplate *
-digest_pseudo_macro(tmap_info_t * minfo, char * real_file);
+static templ_t *
+digest_tpl(tmap_info_t * minfo, char * fname);
 /* = = = END-STATIC-FORWARD = = = */
 
 /**
  * Return the template structure matching the name passed in.
  */
-LOCAL tTemplate *
-findTemplate(char const * pzTemplName)
+LOCAL templ_t *
+find_tpl(char const * pzTemplName)
 {
-    tTemplate * pT = pNamedTplList;
+    templ_t * pT = named_tpls;
     while (pT != NULL) {
-        if (streqvcmp(pzTemplName, pT->pzTplName) == 0)
+        if (streqvcmp(pzTemplName, pT->td_name) == 0)
             break;
-        pT = (tTemplate*)(void*)(pT->pNext);
+        pT = (templ_t*)(void*)(pT->td_scan);
     }
     return pT;
 }
@@ -58,15 +56,15 @@ findTemplate(char const * pzTemplName)
 /**
  * the name is a regular file with read access
  */
-static ag_bool
+static bool
 read_okay(char const * pzFName)
 {
     struct stat stbf;
     if (stat(pzFName, &stbf) != 0)
-        return AG_FALSE;
+        return false;
     if (! S_ISREG(stbf.st_mode))
-        return AG_FALSE;
-    return (access(pzFName, R_OK) == 0) ? AG_TRUE : AG_FALSE;
+        return false;
+    return (access(pzFName, R_OK) == 0) ? true : false;
 }
 
 
@@ -75,10 +73,10 @@ read_okay(char const * pzFName)
  *  list trying to find the base template file name.
  */
 LOCAL tSuccess
-findFile(char const * pzFName,
-         char * pzFullName,
-         char const * const * papSuffixList,
-         char const * pzReferrer)
+find_file(char const * pzFName,
+          char * pzFullName,
+          char const * const * papSuffixList,
+          char const * pzReferrer)
 {
     char * pzRoot;
     char * pzSfx;
@@ -243,13 +241,13 @@ cnt_macros(char const * pz)
 {
     size_t  ct = 2;
     for (;;) {
-        pz = strstr(pz, zStartMac);
+        pz = strstr(pz, st_mac_mark);
         if (pz == NULL)
             break;
         ct += 2;
-        if (strncmp(pz - endMacLen, zEndMac, endMacLen) == 0)
+        if (strncmp(pz - end_mac_len, end_mac_mark, end_mac_len) == 0)
             ct--;
-        pz += startMacLen;
+        pz += st_mac_len;
     }
     return ct;
 }
@@ -261,29 +259,29 @@ cnt_macros(char const * pz)
  *  Load the macro array and file name.
  */
 static void
-load_macs(tTemplate * pT, char const * pzF, char const * pzN,
+load_macs(templ_t * pT, char const * pzF, char const * pzN,
           char const * pzData)
 {
-    tMacro* pMac   = pT->aMacros;
+    macro_t* pMac   = pT->td_macros;
 
     {
-        char*   pzText = (char*)(pMac + pT->macroCt);
+        char*   pzText = (char*)(pMac + pT->td_mac_ct);
         size_t  len;
 
-        AGDUPSTR(pT->pzTplFile, pzF, "templ file");
+        AGDUPSTR(pT->td_file, pzF, "templ file");
 
         len = strlen(pzN) + 1;
         memcpy((void*)pzText, (void*)pzN, len);
-        pT->pzTplName   = pzText;
-        pzText         += len;
-        pT->pzTemplText = pzText;
-        pT->pNext       = pzText + 1;
+        pT->td_name = pzText;
+        pzText     += len;
+        pT->td_text = pzText;
+        pT->td_scan = pzText + 1;
     }
 
-    pCurTemplate = pT;
+    current_tpl = pT;
 
     {
-        tMacro* pMacEnd = parseTemplate(pMac, &pzData);
+        macro_t* pMacEnd = parse_tpl(pMac, &pzData);
         int     ct;
 
         /*
@@ -298,22 +296,22 @@ load_macs(tTemplate * pT, char const * pzF, char const * pzN,
          *  IF there are empty macro slots,
          *  THEN pack the text
          */
-        if (ct < pT->macroCt) {
-            int     delta = sizeof(tMacro) * (pT->macroCt - ct);
+        if (ct < pT->td_mac_ct) {
+            int     delta = sizeof(macro_t) * (pT->td_mac_ct - ct);
             void*   data  =
-                (pT->pzTplName == NULL) ? pT->pzTemplText : pT->pzTplName;
-            size_t  size  = pT->pNext - (char*)data;
+                (pT->td_name == NULL) ? pT->td_text : pT->td_name;
+            size_t  size  = pT->td_scan - (char*)data;
             memmove((void*)pMacEnd, data, size);
 
-            pT->pzTemplText -= delta;
-            pT->pNext       -= delta;
-            pT->pzTplName   -= delta;
-            pT->macroCt      = ct;
+            pT->td_text  -= delta;
+            pT->td_scan  -= delta;
+            pT->td_name  -= delta;
+            pT->td_mac_ct = ct;
         }
     }
 
-    pT->descSize = pT->pNext - (char*)pT;
-    pT->pNext    = NULL;
+    pT->td_size = pT->td_scan - (char*)pT;
+    pT->td_scan = NULL;
 
     /*
      *  We cannot reallocate a smaller array because
@@ -325,18 +323,24 @@ load_macs(tTemplate * pT, char const * pzF, char const * pzN,
         static char const zSum[] =
             "loaded %d macros from %s\n"
             "\tBinary template size:  0x%zX\n\n";
-        fprintf(pfTrace, zSum, pT->macroCt, pzF, pT->descSize);
+        fprintf(trace_fp, zSum, pT->td_mac_ct, pzF, pT->td_size);
     }
 #endif
 }
 
 /**
- * Process the stuff in the pseudo macro.
+ * Load a template from mapped memory.  Load up the pseudo macro,
+ * count the macros, allocate the data, and parse all the macros.
+ *
+ * @param[in] minfo  information about the mapped memory.
+ * @param[in] fname  the full path input file name.
+ *
+ * @returns the digested data
  */
-static tTemplate *
-digest_pseudo_macro(tmap_info_t * minfo, char * real_file)
+static templ_t *
+digest_tpl(tmap_info_t * minfo, char * fname)
 {
-    tTemplate * pRes;
+    templ_t * res;
 
     /*
      *  Count the number of macros in the template.  Compute
@@ -344,37 +348,37 @@ digest_pseudo_macro(tmap_info_t * minfo, char * real_file)
      *  and the size of the template data.  These may get reduced
      *  by comments.
      */
-    char const * pzData =
-        loadPseudoMacro((char const *)minfo->txt_data, real_file);
+    char const * dta =
+        loadPseudoMacro((char const *)minfo->txt_data, fname);
 
-    size_t macroCt  = cnt_macros(pzData);
-    size_t alocSize = (sizeof(*pRes) + (macroCt * sizeof(tMacro))
+    size_t mac_ct   = cnt_macros(dta);
+    size_t alloc_sz = (sizeof(*res) + (mac_ct * sizeof(macro_t))
                        + minfo->txt_size
-                       - (pzData - (char const *)minfo->txt_data)
-                       + strlen(real_file) + 0x10) & ~0x0F;
+                       - (dta - (char const *)minfo->txt_data)
+                       + strlen(fname) + 0x10) & ~0x0F;
 
-    pRes = (tTemplate*)AGALOC(alocSize, "main template");
-    memset((void*)pRes, 0, alocSize);
+    res = (templ_t*)AGALOC(alloc_sz, "main template");
+    memset((void*)res, 0, alloc_sz);
 
     /*
      *  Initialize the values:
      */
-    pRes->magic     = magicMark;
-    pRes->descSize  = alocSize;
-    pRes->macroCt   = macroCt;
+    res->td_magic  = magic_marker;
+    res->td_size   = alloc_sz;
+    res->td_mac_ct = mac_ct;
 
-    strcpy(pRes->zStartMac, zStartMac); /* must fit */
-    strcpy(pRes->zEndMac, zEndMac);     /* must fit */
-    load_macs(pRes, real_file, PSEUDO_MAC_TPL_FILE, pzData);
+    strcpy(res->td_start_mac, st_mac_mark); /* must fit */
+    strcpy(res->td_end_mac,   end_mac_mark);   /* must fit */
+    load_macs(res, fname, PSEUDO_MAC_TPL_FILE, dta);
 
-    pRes->pzTplName   -= (long)pRes;
-    pRes->pzTemplText -= (long)pRes;
-    pRes = (tTemplate*)AGREALOC((void*)pRes, pRes->descSize,
+    res->td_name -= (long)res;
+    res->td_text -= (long)res;
+    res = (templ_t*)AGREALOC((void*)res, res->td_size,
                                 "resize template");
-    pRes->pzTplName   += (long)pRes;
-    pRes->pzTemplText += (long)pRes;
+    res->td_name += (long)res;
+    res->td_text += (long)res;
 
-    return pRes;
+    return res;
 }
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -382,21 +386,21 @@ digest_pseudo_macro(tmap_info_t * minfo, char * real_file)
  *  Starting with the current directory, search the directory
  *  list trying to find the base template file name.
  */
-LOCAL tTemplate *
-loadTemplate(char const * pzFileName, char const * referrer)
+LOCAL templ_t *
+tpl_load(char const * fname, char const * referrer)
 {
-    static tmap_info_t mapInfo;
+    static tmap_info_t map_info;
     static char        tpl_file[ AG_PATH_MAX ];
 
     /*
      *  Find the template file somewhere
      */
     {
-        static char const * const apzSfx[] = {
+        static char const * const sfx_list[] = {
             LOAD_TPL_SFX_TPL, LOAD_TPL_SFX_AGL, NULL };
-        if (! SUCCESSFUL(findFile(pzFileName, tpl_file, apzSfx, referrer))) {
+        if (! SUCCESSFUL(find_file(fname, tpl_file, sfx_list, referrer))) {
             errno = ENOENT;
-            AG_CANT(LOAD_TPL_CANNOT_MAP, pzFileName);
+            AG_CANT(LOAD_TPL_CANNOT_MAP, fname);
         }
     }
 
@@ -407,22 +411,22 @@ loadTemplate(char const * pzFileName, char const * referrer)
     {
         struct stat stbf;
         if (stat(tpl_file, &stbf) != 0)
-            AG_CANT(LOAD_TPL_CANNOT_STAT, pzFileName);
+            AG_CANT(LOAD_TPL_CANNOT_STAT, fname);
 
         if (! S_ISREG(stbf.st_mode)) {
             errno = EINVAL;
-            AG_CANT(LOAD_TPL_IRREGULAR, pzFileName);
+            AG_CANT(LOAD_TPL_IRREGULAR, fname);
         }
 
-        if (outTime <= stbf.st_mtime)
-            outTime = stbf.st_mtime + 1;
+        if (outfile_time < stbf.st_mtime)
+            outfile_time = stbf.st_mtime;
     }
 
-    text_mmap(tpl_file, PROT_READ|PROT_WRITE, MAP_PRIVATE, &mapInfo);
-    if (TEXT_MMAP_FAILED_ADDR(mapInfo.txt_data))
+    text_mmap(tpl_file, PROT_READ|PROT_WRITE, MAP_PRIVATE, &map_info);
+    if (TEXT_MMAP_FAILED_ADDR(map_info.txt_data))
         AG_ABEND(aprf(LOAD_TPL_CANNOT_OPEN, tpl_file));
 
-    if (pfDepends != NULL)
+    if (dep_fp != NULL)
         add_source_file(tpl_file);
 
     /*
@@ -430,75 +434,80 @@ loadTemplate(char const * pzFileName, char const * referrer)
      *  starts immediately after it.
      */
     {
-        tMacro    * pSaveMac = pCurMacro;
-        tTemplate * pRes;
-        pCurMacro = NULL;
+        macro_t * sv_mac = cur_macro;
+        templ_t * res;
+        cur_macro = NULL;
 
-        pRes = digest_pseudo_macro(&mapInfo, tpl_file);
-        pCurMacro = pSaveMac;
-        text_munmap(&mapInfo);
+        res = digest_tpl(&map_info, tpl_file);
+        cur_macro = sv_mac;
+        text_munmap(&map_info);
 
-        return pRes;
+        return res;
     }
 }
 
 /**
- * Deallocate anything we allocated related to a template,
- * including the pointer passed in.
+ * Deallocate anything related to a template.
+ * This includes the pointer passed in and any macros that have an
+ * unload procedure associated with it.
+ *
+ *  @param[in] tpl  the template to unload
  */
 LOCAL void
-unloadTemplate(tTemplate* pT)
+tpl_unload(templ_t * tpl)
 {
-    tMacro* pMac = pT->aMacros;
-    int ct = pT->macroCt;
+    macro_t * mac = tpl->td_macros;
+    int ct = tpl->td_mac_ct;
 
     while (--ct >= 0) {
-        tpUnloadProc proc;
-        unsigned int ix = pMac->funcCode;
+        unload_proc_p_t proc;
+        unsigned int ix = mac->md_code;
 
         /*
          * "select" functions get remapped, depending on the alias used for
-         * the selection.  See the "teFuncType" enumeration in functions.h.
+         * the selection.  See the "mac_func_t" enumeration in functions.h.
          */
         if (ix >= FUNC_CT)
             ix = FTYP_SELECT;
 
-        proc = apUnloadProc[ ix ];
+        proc = unload_procs[ ix ];
         if (proc != NULL)
-            (*proc)(pMac);
+            (*proc)(mac);
 
-        pMac++;
+        mac++;
     }
 
-    AGFREE((void*)(pT->pzTplFile));
-    AGFREE(pT);
+    AGFREE((void*)(tpl->td_file));
+    AGFREE(tpl);
 }
 
 /**
  *  This gets called when all is well at the end.
+ *  The supplied template and all named templates are unloaded.
+ *
+ *  @param[in] tpl  the last template standing
  */
 LOCAL void
-cleanup(tTemplate* pTF)
+cleanup(templ_t * tpl)
 {
     if (HAVE_OPT(USED_DEFINES))
         print_used_defines();
 
-    if (pfDepends != NULL)
+    if (dep_fp != NULL)
         wrap_up_depends();
 
     optionFree(&autogenOptions);
 
     for (;;) {
-        tTemplate* pT = pNamedTplList;
-        if (pT == NULL)
+        tpl_unload(tpl);
+        tpl = named_tpls;
+        if (tpl == NULL)
             break;
-        pNamedTplList = (tTemplate*)(void*)(pT->pNext);
-        unloadTemplate(pT);
+        named_tpls = (templ_t*)(void*)(tpl->td_scan);
     }
 
-    AGFREE(forInfo.fi_data);
-    unloadTemplate(pTF);
-    unloadDefs();
+    free_for_context(true);
+    unload_defs();
 }
 
 /*
